/*
 * Copyright (c) 2001-2006 NeuStar, Inc. All Rights Reserved.
 *
 * $Id: EppResponseDataCheckSvcsub.java,v 1.2 2006/03/01 01:35:38 wtan Exp $
 */
package com.neulevel.epp.core.response;

import org.w3c.dom.*;
import com.neulevel.epp.core.*;

/**
 * This <code>EppResponseDataCheckSvcsub</code> class implements EPP
 * Response Data entity for EPP Command Check of EPP Svcsub objects.
 *
 * @author Ning Zhang ning.zhang@neustar.com
 * @version $Revision: 1.2 $ $Date: 2006/03/01 01:35:38 $
 */
public class EppResponseDataCheckSvcsub extends EppResponseDataCheck
{
	private String service;

	/**
	 * Checks an <code>EppResponseDataCheckSvcsub</code> object
	 */
	public EppResponseDataCheckSvcsub()
	{
		this.service = null;
	}

	/**
	 * Gets the service name
	 */
	public String getService()
	{
		return this.service;
	}

	/**
	 * Sets the service name
	 */
	public void setService( String service )
	{
		this.service = service;
	}

	/**
	 * Converts an XML element into an
	 * <code>EppResponseDataCheckSvcsub</code> object. The caller of this
	 * method must make sure that the root node is the resData element of
	 * EPP responseType for checking EPP Svcsub objects.
	 *
	 * @param root root node for an
	 *             <code>EppResponseDataCheckSvcsub</code> object
	 *             in XML format
	 *
	 * @return an <code>EppResponseDataCheckSvcsub</code> object, or null
	 *         if the node is invalid
	 */
	public static EppEntity fromXML( Node root )
	{
		EppResponseDataCheckSvcsub rsp = new EppResponseDataCheckSvcsub();
		rsp.fromXMLCommon(root, "id");
		NodeList list = root.getChildNodes();
		for( int i = 0; i < list.getLength(); i++ )
		{
			Node node = list.item(i);
			String name = node.getLocalName();
			if( name == null )
			{
				continue;
			}
			if( name.equals("service") )
			{
				String service = EppUtil.getText(node);
				if( service != null )
				{	
					rsp.setService(service);
				}
				break;
			}
		}

		return rsp;
	}

	/**
	 * Converts an <code>EppResponseDataCheckSvcsub</code> object into
	 * an XML element.
	 *
	 * @param doc the XML <code>Document</code> object
	 * @param tag the tag/element name for the
	 *            <code>EppResponseDataCheckSvcsub</code> object
	 *
	 * @return an <code>Element</code> object
	 */
	public Element toXML( Document doc, String tag )
	{
		Element elm;
		Element body = doc.createElement(tag);
		Element data = EppUtil.createElementNS(doc, "svcsub", "chkData");
		body.appendChild(data);
		if( service != null )
		{
			elm = doc.createElement("service");
			elm.appendChild(doc.createTextNode(service));
			data.appendChild(elm);
		}
		toXMLCommon(doc, data, "id");

		return body;
	}
}
