/*
 * Copyright (c) 2001-2006 NeuStar, Inc. All Rights Reserved.
 *
 * $Id: EppResponseDataRenewDomain.java,v 1.2 2006/03/01 01:35:38 wtan Exp $
 */
package com.neulevel.epp.core.response;

import java.util.*;
import com.neulevel.epp.core.*;
import org.w3c.dom.*;
import org.apache.xerces.dom.*;

/**
 * This <code>EppResponseDataRenewDomain</code> class implements EPP
 * Response Data entity for EPP Command Renew of EPP Domain objects.
 *
 * @author Ning Zhang ning.zhang@neustar.com
 * @version $Revision: 1.2 $ $Date: 2006/03/01 01:35:38 $
 */
public class EppResponseDataRenewDomain extends EppResponseDataRenew
{
	private String   name;

	/**
	 * Creates an <code>EppResponseDataRenewDomain</code> object
	 *
	 * @param name the name of the <code>EppDomain</code> object renewed
	 */
	public EppResponseDataRenewDomain( String name )
	{
		this.name = name;
		this.exDate = null;
	}

	/**
	 * Creates an <code>EppResponseDataRenewDomain</code> object
	 *
	 * @param name the name of the <code>EppDomain</code> object renewed
	 * @param exDate the expiration date of the <code>EppDomain</code>
	 *               object renewed
	 */
	public EppResponseDataRenewDomain( String name, Calendar exDate )
	{
		this.name = name;
		this.exDate = exDate;
	}

	/**
	 * Gets the name of the domain renewed
	*/
	public String getName()
	{
		return this.name;
	}

	/**
	 * Sets the name of the domain renewed
	 */
	public void setName( String name )
	{
		this.name = name;
	}

	/**
	 * Converts an XML element into an
	 * <code>EppResponseDataRenewDomain</code> object. The caller of this
	 * method must make sure that the root node is the resData element of
	 * EPP responseType for renewing an EPP Domain object
	 *
	 * @param root root node for an <code>EppResponseDataRenewDomain</code>
	 *             object in XML format
	 *
	 * @return an <code>EppResponseDataRenewDomain</code> object,
	 *         or null if the node is invalid
	 */
	public static EppEntity fromXML( Node root )
	{
		String domain = null;
		Calendar exDate = null;
		NodeList list = root.getChildNodes();
		for( int i = 0; i < list.getLength(); i++ )
		{
			Node node = list.item(i);
			String name = node.getLocalName();
			if( name == null )
			{
				continue;
			}
			else if( name.equals("name") )
			{
				domain = EppUtil.getText(node);
			}
			else if( name.equals("exDate") )
			{
				exDate = EppUtil.getDate(node);
			}
		}

		return new EppResponseDataRenewDomain(domain, exDate);
	}

	/**
	 * Converts an <code>EppResponseDataRenewDomain</code> object
	 * into an XML element.
	 *
	 * @param doc the XML <code>Document</code> object
	 * @param tag the tag/element name for the
	 *        <code>EppResponseDataRenewDomain</code> object
	 *
	 * @return an <code>Element</code> object
	 */
	public Element toXML( Document doc, String tag )
	{
		Element elm;
		Element body = doc.createElement(tag);
		ElementNSImpl data = EppUtil.createElementNS(doc, "domain", "renData");
		body.appendChild(data);

		if( name != null )
		{
			elm = doc.createElement("name");
			elm.appendChild(doc.createTextNode(name));
			data.appendChild(elm);
		}
		if( exDate != null )
		{
			elm = doc.createElement("exDate");
			elm.appendChild(EppUtil.createTextNode(doc, exDate));
			data.appendChild(elm);
		}

		return body;
	}
}
